/*
 * gpio_con.h
 *
 *  Created on: 28 Nov 2017
 *      Author: BinderT
 */
/**@file
 * @addtogroup GPIO
 * @ingroup GPIO
 * @brief GPIO HAL.
 * @details GPIO setup for IOEXP. Holding input event handlers and setting inputs and outputs.
 *
 * @defgroup nrf_drv_uart UART driver
 * @{
 * @ingroup  nrf_uart
 *
 * @brief    UART driver.
 */
#ifndef GPIO_CON_H_
#define GPIO_CON_H_

#include "pin_def.h"

#include <stdio.h>
#include <stdlib.h>
#include <stdint.h>
#include <string.h>
#include "nrf.h"
#include "app_error.h"
#include "nrf_delay.h"
#include "nrf_gpiote.h"
#include "nrf_drv_gpiote.h"
#include "pin_def.h"
#include "app_button.h"
#include "app_gpiote.h"


#include "SEGGER_RTT.h"
#include "SEGGER_RTT_Conf.h"

#define APP_GPIOTE_MAX_USERS 1

#define BUTTON_DEBOUNCE_DELAY 2000


/**
 * @brief User button callback.
 *
 * Action that will be taken when the user button is pressed.
 *
 * @param[in] pin    			Pin number that triggered the call backs.
 * @param[in] action      		Action that triggered the event.
 *
 */
void user_button_handle(nrf_drv_gpiote_pin_t pin, nrf_gpiote_polarity_t action);










/******************
 * config gpio
 ******************/

/**
 * @brief Start GPIO module.
 * This function sets GPIO module to active state
 */
void gpio_init_start(void);
/**
 * @brief Function for setting a GPIO as input with Hi to LOW.
 *
 * @param[in] PIN_IN    			Pin number that will be used as input.
 * @param[in] event_handle      	Pointer to event handler.
 *
 */
void gpio_init_input(nrf_drv_gpiote_pin_t PIN_IN,nrf_drv_gpiote_evt_handler_t event_handle);
/**
 * @brief Function for setting a GPIO as input with toggle.
 *
 * @param[in] PIN_IN    			Pin number that will be used as input.
 * @param[in] event_handle      	Pointer to event handler.
 *
 */
void gpio_init_input_user(nrf_drv_gpiote_pin_t PIN_IN,nrf_drv_gpiote_evt_handler_t event_handle);
/**
 * @brief  Function for setting a GPIO as output.
 *
 * @param[in] PIN_OUT    			Pin number that will be used as output.
 *
 */
void gpio_init_output(nrf_drv_gpiote_pin_t PIN_OUT);
/**
 * @brief Function for Setup the IOEXP GPIO.
 *  This function set all the GPIO as input or output for the IOEXP
 */
void gpio_init(void);


#endif /* GPIO_CON_H_ */
