#include <stdint.h>
#include <string.h>

#include "nrf_log.h"
#include "nrf_log_ctrl.h"
#include "nrf_log_default_backends.h"

#include "gpio_con.h"
#include "timer_hal.h"
#include "power_management.h"
#include "ble_config.h"
#include "ble_hal.h"
#include "service_hal.h"

#include "SEGGER_RTT.h"
#include "SEGGER_RTT_Conf.h"

#define DEAD_BEEF                           0xDEADBEEF                              /**< Value used as error code on stack dump, can be used to identify stack location on stack unwind. */

//static ble_uuid_t m_adv_uuids[] = {};                                 /**< Universally unique service identifiers. */



/**@brief Callback function for asserts in the SoftDevice.
 *
 * @details This function will be called in case of an assert in the SoftDevice.
 *
 * @warning This handler is an example only and does not fit a final product. You need to analyze
 *          how your product is supposed to react in case of Assert.
 * @warning On assert from the SoftDevice, the system can only recover on reset.
 *
 * @param[in] line_num   Line number of the failing ASSERT call.
 * @param[in] file_name  File name of the failing ASSERT call.
 */
void assert_nrf_callback(uint16_t line_num, const uint8_t * p_file_name)
{
    app_error_handler(DEAD_BEEF, line_num, p_file_name);
}

/**@brief Function for initializing the nrf log module.
 */
static void log_init(void)
{
    ret_code_t err_code = NRF_LOG_INIT(NULL);
    APP_ERROR_CHECK(err_code);

    NRF_LOG_DEFAULT_BACKENDS_INIT();
}

/**@brief Function for application main entry.
 */
int main(void)
{
    bool erase_bonds = false;

    // Initialize.
    log_init();
    SEGGER_RTT_printf(0, "\n\rProgram Start\n\r");
    timers_init();
    power_management_init();
    ble_stack_init();
    services_init();
    gpio_init();
    ble_init();
    // Start execution.
    //NRF_LOG_INFO("Heart Rate Sensor example started.");
    application_timers_start();
    advertising_start(erase_bonds);

    // Enter main loop.
    for (;;)
    {
    	nrf_gpio_pin_write(LED_PIN, LED_OFF);
    	nrf_delay_ms(100);
    	nrf_gpio_pin_write(LED_PIN, LED_ON);
    	nrf_delay_ms(100);

        idle_state_handle();
    }
}


