/*
 * service_hal.c
 *
 *  Created on: 13 May 2019
 *      Author: BinderT
 */

#include "service_hal.h"


NRF_BLE_QWR_DEF(m_qwr);                                             /**< Context for the Queued Write module.*/
BLE_DEVICE_INFO_SERVICE_DEF(device_info);

/**@brief Function for handling Queued Write Module errors.
 *
 * @details A pointer to this function will be passed to each service which may need to inform the
 *          application about an error.
 *
 * @param[in]   nrf_error   Error code containing information about what went wrong.
 */
static void nrf_qwr_error_handler(uint32_t nrf_error)
{
    APP_ERROR_HANDLER(nrf_error);
}


static void device_info_evt_handler(ble_device_info_service_t * p_service,ble_device_info_service_evt_t * p_evt){

	switch(p_evt->evt_type){
	case BLE_DEVICE_INFO_DFU_EVT_NOTIFICATION_ENABLED:
		SEGGER_RTT_printf(0, "[%s %s %d]BLE_DEVICE_INFO_DFU_EVT_NOTIFICATION_ENABLED\n\r",__FILE__,__func__,__LINE__);
		break;
	case BLE_DEVICE_INFO_DFU_EVT_NOTIFICATION_DISABLE:
		SEGGER_RTT_printf(0, "[%s %s %d]BLE_DEVICE_INFO_DFU_EVT_NOTIFICATION_DISABLE\n\r",__FILE__,__func__,__LINE__);
		break;
	case BLE_DEVICE_INFO_DFU_EVT_WRITE:
		SEGGER_RTT_printf(0, "[%s %s %d]BLE_DEVICE_INFO_DFU_EVT_WRITE 0x%02x\n\r",__FILE__,__func__,__LINE__,p_evt->params.ble_dfu_state_local);
		break;
	}
}


void io_controle_evt_handler(ble_io_controle_service_t * p_service,ble_io_controle_service_evt_t * p_evt){

	switch(p_evt->evt_type){
		case BLE_IO_CONTROLE_GPIO0_EVT_NOTIFICATION_ENABLED:
			SEGGER_RTT_printf(0, "[%s %s %d]BLE_IO_CONTROLE_GPIO0_EVT_NOTIFICATION_ENABLED\n\r",__FILE__,__func__,__LINE__);
			break;
		case BLE_IO_CONTROLE_GPIO0_EVT_NOTIFICATION_DISABLE:
			SEGGER_RTT_printf(0, "[%s %s %d]BLE_IO_CONTROLE_GPIO0_EVT_NOTIFICATION_ENABLED\n\r",__FILE__,__func__,__LINE__);
			break;
		case BLE_IO_CONTROLE_GPIO0_EVT_WRITE:
			SEGGER_RTT_printf(0, "[%s %s %d]BLE_IO_CONTROLE_GPIO0_EVT_WRITE 0x%02x\n\r",__FILE__,__func__,__LINE__,p_evt->params.ble_gpio0_state_local);
			break;

		default:
			break;
		}

}



/**@brief Function for initializing services that will be used by the application.
 *
 * @details Initialize the Heart Rate, Battery and Device Information services.
 */
void services_init(void)
{
    ret_code_t         err_code;
    nrf_ble_qwr_init_t qwr_init = {0};

    // Initialize Queued Write Module.
    qwr_init.error_handler = nrf_qwr_error_handler;

    err_code = nrf_ble_qwr_init(&m_qwr, &qwr_init);
    APP_ERROR_CHECK(err_code);

    ble_device_info_service_init_t  device_info_init;
    memset(&device_info_init,0,sizeof(device_info_init));

    device_info_init.evt_handler = device_info_evt_handler;

    ble_device_info_service_init(&device_info,&device_info_init);

    ble_io_controle_service_init_t  io_controle_init;

    memset(&io_controle_init,0,sizeof(io_controle_init));

    io_controle_init.evt_handler = io_controle_evt_handler;

    ble_io_controle_service_init(&io_controle,&io_controle_init);


}




