/*
 * device_info.h
 *
 *  Created on: 13 May 2019
 *      Author: BinderT
 */

#ifndef SVR_DEVICE_INFO_H_
#define SVR_DEVICE_INFO_H_


#include <stdint.h>
#include <string.h>

#include "ble.h"
#include "ble_gatts.h"
#include "ble_srv_common.h"


#include "SEGGER_RTT.h"
#include "SEGGER_RTT_Conf.h"


#define DEVICE_INFO_SERVICE_UUID {{ 0x9b,0xe5,0x01,0xf6,0xa9,0xc5,0x4b,0xff,0x9b,0x35,0xab,0xa7,0x90,0xe9,0x80,0x01 }}

#define DEVICE_INFO_SERVICE 0x0001
#define DEVICE_INFO_DFU 0x0002

#define DFU_STATE_DATA_TRX_LEN 20



/**@brief  event type. */
typedef enum {
	BLE_DEVICE_INFO_DFU_EVT_NOTIFICATION_ENABLED,
	BLE_DEVICE_INFO_DFU_EVT_NOTIFICATION_DISABLE,
	BLE_DEVICE_INFO_DFU_EVT_WRITE,

} ble_device_info_service_evt_type_t;

typedef struct ble_device_info_service_s ble_device_info_service_t;

/** @brief dfu_state_in.
 *
 *  General information:
 *      - UUID:
 *      - Type:
 *      - Requirement: Mandatory
 */
typedef struct {
	/** @brief DFU_STATE_IN.
	 *
	 *  - Requirement:  Mandatory
	 *  - Format:       uint8
	 */
	uint8_t dfu_state_in;
} ble_dfu_state_t;

/**@brief Service event. */
typedef struct {
	ble_device_info_service_evt_type_t evt_type; /**< Type of event. */
	union {
		uint16_t cccd_value; /**< Holds decoded data in Notify and Indicate event handler. */
		ble_dfu_state_t ble_dfu_state_local; /**< Holds decoded data in Write event handler. */
	} params;
} ble_device_info_service_evt_t;

typedef void (*ble_device_info_service_evt_handler_t)(ble_device_info_service_t * p_service,
		ble_device_info_service_evt_t * p_evt);


/**@brief Service structure. This contains various status information for the service.*/
struct ble_device_info_service_s {
	ble_device_info_service_evt_handler_t evt_handler; /**< Event handler to be called for handling events in the Service. */
	uint16_t service_handle; /**< Handle of Service (as provided by the BLE stack). */
	ble_gatts_char_handles_t ble_dfu_state_handles; /**< Handles related to the NETWORK_DATA_TRX characteristic. */
	uint16_t conn_handle; /**< Handle of the current connection (as provided by the BLE stack, is BLE_CONN_HANDLE_INVALID if not in a connection). */
	uint8_t uuid_type;
};

/**@brief  Service init structure. This contains all options and data needed for initialization of the service. */
typedef struct {
	ble_device_info_service_evt_handler_t evt_handler; /**< Event handler to be called for handling events in the Service. */
	ble_dfu_state_t ble_dfu_state_initial_value; /**< If not NULL, initial value of the characteristic. */

} ble_device_info_service_init_t;


#define BLE_DEVICE_INFO_SERVICE_DEF(_name) 		\
static ble_device_info_service_t _name;			\
NRF_SDH_BLE_OBSERVER(_name ## _obs,					\
                     BLE_HRS_BLE_OBSERVER_PRIO,     \
					 ble_device_info_service_on_ble_evt, &_name)


/**@brief Function for initializing the .
 *
 * @param[out]  p_
 * @param[in]   p_
 * @return      NRF_SUCCESS on successful initialization of service, otherwise an error code.
 */
uint32_t ble_device_info_service_init(
		ble_device_info_service_t * p_service,
		const ble_device_info_service_init_t * p_service_init);

/**@brief Function for handling the Application's BLE Stack events.*/
void ble_device_info_service_on_ble_evt(
		ble_evt_t const * p_ble_evt,
		void * p_context);

uint32_t ble_device_info_service_dfu_send(
		ble_device_info_service_t * p_service,
		ble_dfu_state_t * p_dfu_state);

uint32_t ble_device_info_service_dfu_set(
		ble_device_info_service_t * p_service,
		ble_dfu_state_t * p_dfu_state);


#endif /* SVR_DEVICE_INFO_H_ */
