/*
 * io_controle.c
 *
 *  Created on: 26 May 2019
 *      Author: BinderT
 */

#include "io_controle.h"


/**@brief Function for encoding
 *
 * @param[in]
 * @param[out]
 *
 * @return      Size of encoded data.
 */

static uint8_t ble_gpio_state_encode(ble_gpio_state_t *p_read_val, uint8_t *p_data)
{
    uint8_t len = 0;

    p_data[0]= p_read_val->gpio_state_in;
    len++;

   return len;
}

/**@brief Function for decoding .
 *
 * @param[in]   data_len              Length of the field to be decoded.
 * @param[in]   p_data                Buffer where the encoded data is stored.
 * @param[out]  p_write_val           Decoded data.
 *
 * @return      Length of the decoded field.
 */

static uint8_t ble_gpio_state_decode(uint8_t data_len, uint8_t const * p_data, ble_gpio_state_t * p_write_val)
{
	uint8_t pos = 0;


	p_write_val->gpio_state_in = p_data[0];

	pos++;

	return pos;
}

/**@brief Function for handling the Connect event.
 *
 * @param[in]   p_service        Service structure.
 * @param[in]   p_ble_evt   Event received from the BLE stack.
 */
static void on_connect(
		ble_io_controle_service_t * p_service,
		ble_evt_t const * p_ble_evt) {
	//SEGGER_RTT_printf(0, "[on_connect]\n\r");
	p_service->conn_handle = p_ble_evt->evt.gap_evt.conn_handle;
}

/**@brief Function for handling the Disconnect event.
 *
 * @param[in]   p_service        Service structure.
 * @param[in]   p_ble_evt   Event received from the BLE stack.
 */
static void on_disconnect(
		ble_io_controle_service_t * p_service,
		ble_evt_t const * p_ble_evt) {
	//SEGGER_RTT_printf(0, "[on_disconnect]\n\r");
	UNUSED_PARAMETER(p_ble_evt);
	p_service->conn_handle = BLE_CONN_HANDLE_INVALID;
}

/**@brief Function for handling the Write event.
 *
 * @param[in]   p_service        Service structure.
 * @param[in]   p_ble_evt   Event received from the BLE stack.
 */
static void on_write(ble_io_controle_service_t * p_service,
		ble_gatts_evt_write_t const * p_ble_evt) {
	//SEGGER_RTT_printf(0, "[on_write]%d\n\r",p_ble_evt->op);

	//if(p_ble_evt->auth_required){
	if (p_ble_evt->handle == p_service->ble_gpio0_state_handles.cccd_handle) {

		if (p_service->evt_handler != NULL) {
			ble_io_controle_service_evt_t evt;

			if(p_ble_evt->data[0] == 1){
				evt.evt_type = BLE_IO_CONTROLE_GPIO0_EVT_NOTIFICATION_ENABLED;
			}else{
				evt.evt_type = BLE_IO_CONTROLE_GPIO0_EVT_NOTIFICATION_DISABLE;
			}

			//SEGGER_RTT_printf(0, "[BLE_DEVICE_INFO_DFU_EVT_NOTIFICATION_ENABLED]%d %d\n\r",p_ble_evt->data[0],p_ble_evt->len);

			p_service->evt_handler(p_service,&evt);
		}

	}
	if (p_ble_evt->handle == p_service->ble_gpio0_state_handles.value_handle) {

		if (p_service->evt_handler != NULL) {
			ble_io_controle_service_evt_t evt;
			evt.evt_type = BLE_IO_CONTROLE_GPIO0_EVT_WRITE;
			ble_gpio_state_decode(p_ble_evt->len,p_ble_evt->data,&evt.params.ble_gpio0_state_local);

			p_service->evt_handler(p_service,&evt);
		}

	}


}

/**@brief Authorize WRITE request event handler.
 *
 * @details Handles WRITE events from the BLE stack.
 *
 * @param[in]   p_sc_ctrlpt  SC Ctrlpt structure.
 * @param[in]   p_gatts_evt  GATTS Event received from the BLE stack.
 *
 */
static void on_rw_authorize_request(
		ble_io_controle_service_t * p_service,
		ble_gatts_evt_t const * p_gatts_evt) {
	//SEGGER_RTT_printf(0, "[on_rw_authorize_request]\n\r");
	ble_gatts_evt_rw_authorize_request_t const * p_auth_req = &p_gatts_evt->params.authorize_request;
	if (p_auth_req->type == BLE_GATTS_AUTHORIZE_TYPE_WRITE) {
		if ((p_gatts_evt->params.authorize_request.request.write.op != BLE_GATTS_OP_PREP_WRITE_REQ)
			&& (p_gatts_evt->params.authorize_request.request.write.op != BLE_GATTS_OP_EXEC_WRITE_REQ_NOW)
			&& (p_gatts_evt->params.authorize_request.request.write.op != BLE_GATTS_OP_EXEC_WRITE_REQ_CANCEL))
		{

			if (p_auth_req->request.write.handle == p_service->ble_gpio0_state_handles.value_handle) {
				on_write(p_service, &p_auth_req->request.write);
			}

		}
	}
}

/**@brief Function for handling BLE events.
 *
 * @param[in]   p_service        Service structure.
 * @param[in]   p_ble_evt   Event received from the BLE stack.
 */
void ble_io_controle_service_on_ble_evt(
		ble_evt_t const * p_ble_evt,
		void * p_context
		) {

	ble_io_controle_service_t *p_service = (ble_io_controle_service_t *) p_context;
	switch (p_ble_evt->header.evt_id) {
	case BLE_GAP_EVT_CONNECTED:
		on_connect(p_service, p_ble_evt);
		break;
	case BLE_GAP_EVT_DISCONNECTED:
		on_disconnect(p_service, p_ble_evt);
		break;
	case BLE_GATTS_EVT_WRITE:
		on_write(p_service,&p_ble_evt->evt.gatts_evt.params.write);
		break;
	case BLE_GATTS_EVT_RW_AUTHORIZE_REQUEST:
		on_rw_authorize_request(p_service,&p_ble_evt->evt.gatts_evt);
		break;
	default:
		//No implementation needed.
		break;
	}
}


/**@brief Function for initializing the . */
uint32_t ble_io_controle_service_init(
		ble_io_controle_service_t * p_service,
		const ble_io_controle_service_init_t * p_service_init) {

	uint32_t err_code;
	ble_uuid_t ble_uuid;

	// Initialize service structure
	p_service->evt_handler = p_service_init->evt_handler;
	p_service->conn_handle = BLE_CONN_HANDLE_INVALID;

	// Add a custom base UUID.
	ble_uuid128_t bds_base_uuid = IO_CONTROLE_SERVICE_UUID;
	// uint8_t       uuid_type;
	err_code = sd_ble_uuid_vs_add(&bds_base_uuid, &p_service->uuid_type);
	if (err_code != NRF_SUCCESS) {
		SEGGER_RTT_printf(0, "[%s %s %d]error: %d\n\r",__FILE__,__func__,__LINE__,err_code);
		return err_code;
	}
	ble_uuid.type = p_service->uuid_type;
	ble_uuid.uuid = IO_CONTROLE_SERVICE;

	// Add dfu service
	err_code = sd_ble_gatts_service_add(BLE_GATTS_SRVC_TYPE_PRIMARY, &ble_uuid, &p_service->service_handle);
	if (err_code != NRF_SUCCESS) {
		SEGGER_RTT_printf(0, "[%s %s %d]error: %d\n\r",__FILE__,__func__,__LINE__,err_code);
		return err_code;
	}

	// Add DFU characteristic
	ble_gpio_state_t gpio0_state_initial_value = p_service_init->ble_gpio0_initial_value;

	uint8_t gpio0_state_encoded_value[sizeof(ble_gpio_state_t)];
	ble_add_char_params_t gpio0_state_params;
	memset(&gpio0_state_params, 0,sizeof(gpio0_state_params));

	gpio0_state_params.uuid 				= IO_CONTROLE_GPIO0;
	gpio0_state_params.uuid_type 			= ble_uuid.type;
	gpio0_state_params.max_len 				= sizeof(ble_gpio_state_t);
	gpio0_state_params.init_len 			= ble_gpio_state_encode(&gpio0_state_initial_value, gpio0_state_encoded_value);
	gpio0_state_params.p_init_value 		= gpio0_state_encoded_value;
	//gpio0_state_params.char_props.notify 	= 1;
	gpio0_state_params.char_props.read	= 1;
	gpio0_state_params.char_props.write	= 1;
	//gpio0_state_params.cccd_write_access 	= SEC_OPEN;
	gpio0_state_params.read_access 	= SEC_OPEN;
	gpio0_state_params.write_access 	= SEC_OPEN;
	// 1 for variable length and 0 for fixed length.
	gpio0_state_params.is_var_len = 1;

	err_code = characteristic_add(p_service->service_handle,
			&gpio0_state_params,
			&(p_service->ble_gpio0_state_handles));
	if (err_code != NRF_SUCCESS) {
		SEGGER_RTT_printf(0, "[%s %s %d]error: %d\n\r",__FILE__,__func__,__LINE__,err_code);
		return err_code;
	}

	return NRF_SUCCESS;
}

/**@brief Function for setting the . */
uint32_t ble_io_controle_service_gpio0_set(
		ble_io_controle_service_t * p_service,
		ble_gpio_state_t * p_gpio_state) {
	//SEGGER_RTT_printf(0,

	ble_gatts_value_t gatts_value;
	uint8_t encoded_value[sizeof(ble_gpio_state_t)];

	// Initialize value struct.
	memset(&gatts_value, 0, sizeof(gatts_value));

	gatts_value.len = ble_gpio_state_encode(p_gpio_state, encoded_value);
	gatts_value.offset = 0;
	gatts_value.p_value = encoded_value;

	return sd_ble_gatts_value_set(p_service->conn_handle,
			p_service->ble_gpio0_state_handles.value_handle,
			&gatts_value);
}









