/*
 * io_controle.h
 *
 *  Created on: 26 May 2019
 *      Author: BinderT
 */

#ifndef SVR_IO_CONTROLE_H_
#define SVR_IO_CONTROLE_H_

#include <stdint.h>
#include <string.h>

#include "ble.h"
#include "ble_gatts.h"
#include "ble_srv_common.h"

#include "SEGGER_RTT.h"
#include "SEGGER_RTT_Conf.h"

#define IO_CONTROLE_SERVICE_UUID {{ 0xd3,0x86,0x54,0x80,0x51,0x08,0x4f,0xe8,0x8e,0xde,0x6e,0xfc,0x7e,0x94,0xf1,0x85 }}

#define IO_CONTROLE_SERVICE 0x0001
#define IO_CONTROLE_GPIO0   0x0002


/**@brief event type. */
typedef enum {
	BLE_IO_CONTROLE_GPIO0_EVT_NOTIFICATION_ENABLED,
	BLE_IO_CONTROLE_GPIO0_EVT_NOTIFICATION_DISABLE,
	BLE_IO_CONTROLE_GPIO0_EVT_WRITE
} ble_io_controle_service_evt_type_t;

typedef struct ble_io_controle_service_s ble_io_controle_service_t;

/** @brief dfu_state_in.
 *
 *  General information:
 *      - UUID:
 *      - Type:
 *      - Requirement: Mandatory
 */
typedef struct {
	/** @brief DFU_STATE_IN.
	 *
	 *  - Requirement:  Mandatory
	 *  - Format:       uint8
	 */
	uint8_t gpio_state_in;
} ble_gpio_state_t;


/**@brief Service event. */
typedef struct {
	ble_io_controle_service_evt_type_t evt_type; /**< Type of event. */
	union {
		uint16_t cccd_value; /**< Holds decoded data in Notify and Indicate event handler. */
		ble_gpio_state_t ble_gpio0_state_local; /**< Holds decoded data in Write event handler. */
	} params;
} ble_io_controle_service_evt_t;

typedef void (*ble_io_controle_service_evt_handler_t)(ble_io_controle_service_t * p_service,
		ble_io_controle_service_evt_t * p_evt);


/**@brief Service structure. This contains various status information for the service.*/
struct ble_io_controle_service_s {
	ble_io_controle_service_evt_handler_t evt_handler; /**< Event handler to be called for handling events in the Service. */
	uint16_t service_handle; /**< Handle of Service (as provided by the BLE stack). */
	ble_gatts_char_handles_t ble_gpio0_state_handles; /**< Handles related to the  characteristic. */
	uint16_t conn_handle; /**< Handle of the current connection (as provided by the BLE stack, is BLE_CONN_HANDLE_INVALID if not in a connection). */
	uint8_t uuid_type;
};

/**@brief Service init structure. This contains all options and data needed for initialization of the service. */
typedef struct {
	ble_io_controle_service_evt_handler_t evt_handler; /**< Event handler to be called for handling events in the Service. */
	ble_gpio_state_t ble_gpio0_initial_value; /**< If not NULL, initial value of the characteristic. */
} ble_io_controle_service_init_t;


#define BLE_IO_CONTROLE_SERVICE_DEF(_name) 		\
ble_io_controle_service_t _name;			\
NRF_SDH_BLE_OBSERVER(_name ## _obs,					\
                     BLE_HRS_BLE_OBSERVER_PRIO,     \
					 ble_io_controle_service_on_ble_evt, &_name)


/**@brief Function for initializing the .
 *
 * @param[out]  p_
 * @param[in]   p_
 * @return      NRF_SUCCESS on successful initialization of service, otherwise an error code.
 */
uint32_t ble_io_controle_service_init(
		ble_io_controle_service_t * p_service,
		const ble_io_controle_service_init_t * p_service_init);

/**@brief Function for handling the Application's BLE Stack events.*/
void ble_io_controle_service_on_ble_evt(
		ble_evt_t const * p_ble_evt,
		void * p_context);


/**@brief Function for setting the . */
uint32_t ble_io_controle_service_gpio0_set(
		ble_io_controle_service_t * p_service,
		ble_gpio_state_t * p_gpio_state);


#endif /* SVR_IO_CONTROLE_H_ */
